@@ -3,10 +3,11 @@ SS_plots <-
     replist=NULL, plot=1:27, print=0, pdf=FALSE, printfolder="plots", dir="default", fleets="all", areas="all",
     fleetnames="default", fleetcols="default", fleetlty=1, fleetpch=1, lwd=1, areacols="default", areanames="default",
     verbose=TRUE, uncertainty=TRUE, forecastplot=FALSE, datplot=FALSE, Natageplot=TRUE, samplesizeplots=TRUE, compresidplots=TRUE,
-    sprtarg=0.4, btarg=0.4, minbthresh=0.25, pntscalar=2.6, minnbubble=8, aalyear=-1, aalbin=-1, 
+    sprtarg="default", btarg="default", minbthresh="default", pntscalar=2.6, minnbubble=8, aalyear=-1, aalbin=-1, 
     aalresids=FALSE, maxneff=5000, cohortlines=c(), smooth=TRUE, showsampsize=TRUE, showeffN=TRUE, showlegend=TRUE,
     pwidth=7, pheight=7, punits="in", ptsize=12, res=300, cex.main=1,selexlines=1:5,
     rows=1, cols=1, maxrows=6, maxcols=6, maxrows2=2, maxcols2=4, tagrows=3, tagcols=3, fixdims=TRUE, new=TRUE,
+    SSplotDatMargin=8,
     catchasnumbers=FALSE,legendloc="topleft", minyr=NULL, maxyr=NULL, scalebins=FALSE, ...)
 {
   ################################################################################
@@ -106,9 +107,9 @@ SS_plots <-
   nplots <- length(intersect(1:50,plot))
   nprints <- length(intersect(1:50,print))
 
+  OS <- "Mac" # don't know the version$os info for Mac
   if(length(grep("linux",version$os)) > 0) OS <- "Linux"
   if(length(grep("mingw",version$os)) > 0) OS <- "Windows"
-  # need appropriate line to support Mac operating systems
 
   if(nprints>0 & pdf){
     stop("can't have pdf=T and print!=0: use print only or pdf & plot inputs")
@@ -275,7 +276,7 @@ SS_plots <-
               plot=(11 %in% plot),
               print=(11 %in% print),
               uncertainty=uncertainty,
-              sprtarg=0.4, btarg=0.4,
+              sprtarg=sprtarg, btarg=btarg,
               pwidth=pwidth, pheight=pheight, punits=punits,
               ptsize=ptsize, res=res,cex.main=cex.main,
               plotdir=plotdir)
@@ -380,7 +381,7 @@ SS_plots <-
                     pwidth=pwidth, pheight=pheight, punits=punits,
                     ptsize=ptsize, res=res,
                     ...)
-        # size comp bar plot
+        # size comp bubble plot
         for(sizemethod in sort(unique(replist$sizedbase$method))){
           SSplotComps(replist=replist,datonly=TRUE,kind="SIZE",sizemethod=sizemethod,
                       bub=TRUE,verbose=verbose,fleets=fleets,fleetnames=fleetnames,
@@ -672,7 +673,8 @@ SS_plots <-
                print=(27 %in% print),
                pwidth=pwidth, pheight=pheight, punits=punits,
                ptsize=ptsize, res=res, cex.main=cex.main,
-               plotdir=plotdir)
+               plotdir=plotdir, margins=c(5.1,2.1,4.1,SSplotDatMargin),
+               fleetnames=fleetnames)
   # end if 27 in plot or print
   
   if(pdf) dev.off() # close PDF file if it was open
